# frozen_string_literal: true

require 'spec_helper'

RSpec.describe Roqua::Healthy::A19::PhoneValidator do
  subject { described_class }

  describe '#phone_cell_number?' do
    it 'detects a Dutch mobile number' do
      expect(subject.phone_cell_number?('+31612345678')).to be_truthy
    end

    it 'rejects a phone number that consists of something other than numbers' do
      expect(subject.phone_cell_number?('0612345678mdr')).to be_falsey
    end

    it 'detects a Dutch mobile number without a country code' do
      expect(subject.phone_cell_number?('0612345678')).to be_truthy
    end

    it 'rejects a normal Dutch phone number' do
      expect(subject.phone_cell_number?('+31592123456')).to be_falsey
    end

    it 'detects a mobile number from Austria' do
      expect(subject.phone_cell_number?('+4365012345678')).to be_truthy
    end

    it 'rejects a normal phone number from Austria' do
      expect(subject.phone_cell_number?('+431123456')).to be_falsey
    end

    it 'rejects a mobile number from China' do
      expect(subject.phone_cell_number?('+8613312345678')).to be_falsey
    end

    it 'rejects a normal phone number from China' do
      expect(subject.phone_cell_number?('+86312123456')).to be_falsey
    end
  end
end
